#!/usr/bin/env python
# CESYS Software License - Version 1.0 - January 1st, 2016
#
# Permission is hereby granted, free of charge, to any person or organization
# obtaining a copy of the software and accompanying documentation covered by
# this license (the "Software") to use, reproduce, display, distribute,
# execute, and transmit the Software, and to prepare derivative works of the
# Software, and to permit third-parties to whom the Software is furnished to
# do so, all subject to the following:
#
# The software must only be used to operate hardware manufactured by 
# CESYS GmbH, Herzogenaurach.
#
# The copyright notices in the Software and this entire statement, including
# the above license grant, this restriction and the following disclaimer,
# must be included in all copies of the Software, in whole or in part, and
# all derivative works of the Software, unless such copies or derivative
# works are solely in the form of machine-executable object code generated by
# a source language processor.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
# SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
# FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
# 
# Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
from CeboMsrApiPython import LibraryInterface, DeviceType

# CeboMsr - Python example - Info.
#
# Print out various information about the device.

def printInformation(device):
    """
    Print various information to the console.
    device: Device to use for test.
    """
    # Put out some device specific information.
    print("Device type: %s" % device.getDeviceType().getName())
    print("API vers: %s" % LibraryInterface.getApiVersion())
    print("Firmware ver: %s" % device.getFirmwareVersion())
    print("Identifier: %s" % device.getIdentifier())
    print("Serial number: %s" % device.getSerialNumber())
    print("Temperature: %.2f" % device.getTemperature())

    # Get the real current of the reference current sources.
    for source in device.getCurrentSources():
        print("Reference current of %s: %.2f uA" % (
            source.getName(),
            source.getReferenceCurrent()))

    # Retrieve information about single ended input #0.
    # This works on all analog inputs and outputs.
    se0 = device.getSingleEndedInputs()[0]
    print("Info for single ended input %s:" % se0.getName())
    print("  Min. ICD: %d us" % se0.getMinInterChannelDelay())
    print("  Current range: %.2f V to %.2f V" % (
        se0.getRange().getMinValue(),
        se0.getRange().getMaxValue()))
    print("  Supported ranges:")
    for i in range(len(se0.getSupportedRanges())):
        rng = se0.getSupportedRanges()[i]
        print("    Range #%d range: %.2f V to %.2f V, Def. ICD: %d us" % (
            i,
            rng.getMinValue(),
            rng.getMaxValue(),
            se0.getDefaultInterChannelDelay(rng)))

    # Get info for digital port #0.
    dp0 = device.getDigitalPorts()[0]
    print("Info for digital port %s:" % dp0.getName())
    print("  Count of I/O's: %d" % dp0.getIoCount())
    for i in range(dp0.getIoCount()):
        print("    I/O #%d: %s" % (i, dp0.getIoName(i)))

def main():
    """
    The examples main method.
    """
    try:
        # Search for devices ...
        devices = LibraryInterface.enumerate(DeviceType.All)

        # If at least one has been found, use the first one ...
        if (len(devices) > 0):
            device = devices[0]

            # Open device, nothing can be done without doing this.
            device.open()

            # Put out info.
            printInformation(device)

            # Finalize device usage, this free's up the device, so it can be used
            # again, including other applications.
            device.close()
    # These exceptions are currently used to report different problems ...
    except AttributeError as e:
        print(e)
    except IndexError as e:
        print(e)
    except SystemError as e:
        print(e)
    except IOError as e:
        print(e)

if (__name__ == "__main__"):
    main()